<?php
/**
 * Dynamic CSS for the frontend.
 *
 * @package Citation
 */

defined( 'WPINC' ) || exit;

/**
 * Helper function.
 * Merge and combine the CSS elements.
 *
 * @param  string|array $elements An array of our elements.
 *                                If we use a string then it is directly returned.
 * @return string
 */
function citation_implode( $elements = array() ) {

	if ( ! is_array( $elements ) ) {
		return $elements;
	}

	// Make sure our values are unique.
	$elements = array_unique( $elements );

	// Sort elements alphabetically.
	// This way all duplicate items will be merged in the final CSS array.
	sort( $elements );

	// Implode items and return the value.
	return implode( ',', $elements );

}

/**
 * Maps elements from dynamic css to the selector.
 *
 * @param  array  $elements The elements.
 * @param  string $selector The selector.
 * @return array
 */
function citation_map_selector( $elements, $selector ) {
	$array = array();

	foreach ( $elements as $element ) {
		$array[] = $element . $selector;
	}

	return $array;
}

/**
 * Map CSS selectors from values.
 *
 * @param array $css    Array of dynamic CSS.
 * @param array $values Array of values.
 */
function citation_map_css_selectors( &$css, $values ) {
	if ( isset( $values['css-selectors'] ) ) {
		$elements = $values['css-selectors'];
		unset( $values['css-selectors'] );

		$css[ $elements ] = $values;
	}
}

/**
 * Merge CSS values.
 *
 * @param array $css    Array of dynamic CSS.
 * @param array $values Array of values.
 */
function citation_merge_value( &$css, $values ) {
	foreach ( (array) $values as $id => $val ) {
		$css[ $id ] = $val;
	}
}

/**
 * Format of the $css array:
 * $css['media-query']['element']['property'] = value
 *
 * If no media query is required then set it to 'global'
 *
 * If we want to add multiple values for the same property then we have to make it an array like this:
 * $css[media-query][element]['property'][] = value1
 * $css[media-query][element]['property'][] = value2
 *
 * Multiple values defined as an array above will be parsed separately.
 */
function citation_dynamic_css_array() {

	global $wp_version;

	$css       = array();
	$c_page_id = citation()->get_page_id();

	// Site Background.
	$css['global']['html body, #sidebar .widget h3 span'] = Citation_Sanitize::background( citation_get_settings( 'mts_background' ) );

	// Header Background.
	$css['global']['.main-header #header, #header.sticky-navigation-active'] = Citation_Sanitize::background( citation_get_settings( 'header_background' ) );
	// Home Header Background.
	$css['global']['.main-header.home-header #header, .main-header.home-header #header.sticky-navigation.sticky-navigation-active'] = Citation_Sanitize::background( citation_get_settings( 'home_header_background' ) );

	// Logo Font.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'citation_logo' ) ) );
	// Primary Navigation font.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'primary_navigation_font' ) ) );
	// Content Font.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'content_font' ) ) );
	// Pagination.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'pagination_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'loadmore_font' ) ) );
	// Archive Pages font.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'archive_post_title_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'archive_post_excerpt_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'archive_meta_info_font' ) ) );
	// Single post title font.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'single_title_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'pages_title_font' ) ) );
	// Single post author info font.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'single_author_meta_info_font' ) ) );
	// Single Page titles font.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'single_page_titles_font' ) ) );
	// Single subscribe box.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'single_subscribe_title_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'single_subscribe_text_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'single_subscribe_input_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'single_subscribe_submit_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'single_subscribe_small_text_font' ) ) );
	// Author Box.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'authorbox_title_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'authorbox_author_name_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'authorbox_text_font' ) ) );
	// Sidebar widget title font.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'sidebar_title_font' ) ) );
	// Sidebar widget font.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'sidebar_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'sidebar_links_widgets' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'sidebar_post_title' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'sidebar_large_post_title' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'sidebar_postinfo_font' ) ) );
	// Footer Nav.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'footer_nav_font' ) ) );
	// Footer widget title font.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'top_footer_title_font' ) ) );
	// Footer widget font.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'top_footer_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'footer_links_widgets' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'top_footer_post_title' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'footer_large_post_title' ) ) );
	// Footer meta font.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'top_footer_meta_font' ) ) );
	// Footer Nav Font
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'footer_nav_font' ) ) );
	// Footer Logo.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'citation_footer_logo' ) ) );
	// Copyrights section font.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'copyrights_font' ) ) );
	// Fields font.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'fields_font' ) ) );
	// H1 title in the content.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'h1_headline' ) ) );
	// H2 title in the content.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'h2_headline' ) ) );
	// H3 title in the content.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'h3_headline' ) ) );
	// H4 title in the content.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'h4_headline' ) ) );
	// H5 title in the content.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'h5_headline' ) ) );
	// H6 title in the content.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'h6_headline' ) ) );

	// Footer background.
	$css['global']['#site-footer'] = Citation_Sanitize::background( citation_get_settings( 'mts_footer_background' ) );
	// Copyrights background.
	$css['global']['.copyrights'] = Citation_Sanitize::background( citation_get_settings( 'mts_copyrights_background' ) );

	citation_dynamic_css_skin( $css );
	citation_sidebar_position( $css );
	citation_header( $css );
	citation_sidebar_styling( $css );
	citation_homepage_settings( $css );
	citation_pages_title( $css );
	citation_post_layouts( $css );
	citation_post_pagination( $css );
	citation_footer( $css );
	citation_copyrights( $css );
	citation_single( $css );
	citation_single_social_buttons( $css );
	citation_archive_post( $css );
	citation_misc_css( $css );

	return apply_filters( 'citation_dynamic_css_array', $css );
}

/**
 * Skin CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function citation_dynamic_css_skin( &$css ) {

	// Colors.
	$primary_color_scheme = Citation_Sanitize::color( citation_get_settings( 'primary_color_scheme' ) );
	$hover_color_scheme   = Citation_Sanitize::color( citation_get_settings( 'primary_hover_color_scheme' ) );

	// Text Color.
	$elements = array(
		'a',
		'body a:hover',
		'.reply a:hover',
		'.reply a .fa',
		'.latestPost .title a:hover',
		'.related-posts .title a:hover',
		'.woocommerce ul.products li.product .price',
		'.product_list_widget .amount',
		'.woocommerce div.product p.price, .woocommerce div.product span.price',
		'.shareit-circular.standard .fa:hover',
		'.textwidget a',
		'#wp-calendar td#today',
		'.pnavigation2 a',
		'#sidebar .widget li a:hover',
		'#sidebar .widget li.horizontal-small .post-title a:hover',
		'#tabber .inside li a:hover',
		'.fn a',
		'.widget .wp_review_tab_widget_content a:hover',
		'.sidebar .wpt_widget_content a:hover',
		'.related-posts .title a:hover',
		'blockquote:after',
		'article ul li::before',
		'.single .pagination a .current:hover',
		'blockquote::before',
		'.postauthor h5 a:hover',
		'#primary-navigation li:hover > a',
		'.related-readmore a',
		'.toggle-menu .toggle-caret .fa',
		'#primary-navigation li.current-menu-item a',
		'.widget .wpt_widget_content #tags-tab-content ul li a',
		'.shareit-circular.standard .share-text',
		'.f-widget .widget li.horizontal-small .post-title a:hover',
		'.layout-default .latestPost .title a:hover',
		'.layout-1 .latestPost .title a:hover',
		'.header-search span.sbutton',
		'#sidebar .widget a:hover',
		'#copyright-note a:hover',
	);

	$css['global'][ citation_implode( $elements ) ]['color'] = $primary_color_scheme;
	//social svg hover color
	$css['global']['.shareit-circular.standard svg:hover']['fill'] = $primary_color_scheme;
	//header layout 2 triangle css
	$css['global']['.header-layout2 #primary-navigation li.menu-item-has-children:after']['border-top-color'] = $primary_color_scheme;

	// Text Color Important.
	$elements = array(
		'.widget .review_thumb_large .review-result',
		'.widget .review_thumb_large .review-total-only.large-thumb',
		'.review-total-only.small-thumb .review-result-wrapper i',
		'.latestPost .post-info a:hover',
		'#sidebar .social-profile-icons ul li a:hover',
		'.widget.widget_archive a:hover',
		'.widget.widget_categories a:hover',
		'.widget.widget_pages a:hover',
		'.widget.widget_meta a:hover',
		'.widget.widget_nav_menu a:hover',
		'.post-title a:hover',
		'.entry-title a:hover',
		'.single_post .post-info a:hover',
		'.widget.widget_categories li a:hover',
		'.widget.widget_archive li a:hover',
		'.widget.widget_pages li a:hover',
		'.widget.widget_meta li a:hover',
		'.widget.widget_recent_comments li a:hover',
		'.widget.widget_recent_entries li a:hover',
		'.widget.widget_rss li a:hover',
		'.widget.widget_nav_menu li a:hover',
	);
	$css['global'][ citation_implode( $elements ) ]['color'] = $primary_color_scheme . '!important';

	// Background Color.
	$elements = array(
		'.pace .pace-progress',
		'#mobile-menu-wrapper ul li a:hover',
		'.navigation #wpmm-megamenu .wpmm-pagination a',
		'.wpmm-megamenu-showing.wpmm-light-scheme',
		'.widget #wp-subscribe input.submit',
		'#tabber ul.tabs li a.selected',
		'.navigation ul .sfHover a',
		'.widget-slider .slide-caption',
		'.owl-prev:hover, .owl-next:hover',
		'.widget .wp-subscribe-wrap h4.title span.decor:after',
		'#wpmm-megamenu .review-total-only',
		'#searchsubmit',
		'.woocommerce .widget_price_filter .ui-slider .ui-slider-handle',
		'.woocommerce .widget_price_filter .ui-slider .ui-slider-range',
		'.woocommerce nav.woocommerce-pagination ul li a:focus',
		'.woocommerce nav.woocommerce-pagination ul li a:hover',
		'.woocommerce .bypostauthor:after',
		'.woocommerce a.button',
		'.woocommerce-page a.button',
		'.woocommerce button.button',
		'.woocommerce-page button.button',
		'.woocommerce input.button',
		'.woocommerce-page input.button',
		'.woocommerce #respond input#submit',
		'.woocommerce-page #respond input#submit',
		'.woocommerce #content input.button',
		'.woocommerce-page #content input.button',
		'.woocommerce #respond input#submit.alt.disabled',
		'.woocommerce #respond input#submit.alt.disabled:hover',
		'.woocommerce #respond input#submit.alt:disabled',
		'.woocommerce #respond input#submit.alt:disabled:hover',
		'.woocommerce #respond input#submit.alt:disabled[disabled]',
		'.woocommerce #respond input#submit.alt:disabled[disabled]:hover',
		'.woocommerce a.button.alt.disabled, .woocommerce a.button.alt.disabled:hover',
		'.woocommerce a.button.alt:disabled',
		'.woocommerce a.button.alt:disabled:hover',
		'.woocommerce a.button.alt:disabled[disabled]',
		'.woocommerce a.button.alt:disabled[disabled]:hover',
		'.woocommerce button.button.alt.disabled',
		'.woocommerce button.button.alt.disabled:hover',
		'.woocommerce button.button.alt:disabled',
		'.woocommerce button.button.alt:disabled:hover',
		'.woocommerce button.button.alt:disabled[disabled]',
		'.woocommerce button.button.alt:disabled[disabled]:hover',
		'.woocommerce input.button.alt.disabled',
		'.woocommerce input.button.alt.disabled:hover',
		'.woocommerce input.button.alt:disabled',
		'.woocommerce input.button.alt:disabled:hover',
		'.woocommerce input.button.alt:disabled[disabled]',
		'.woocommerce input.button.alt:disabled[disabled]:hover',
		'#add_payment_method .wc-proceed-to-checkout a.checkout-button',
		'.woocommerce-cart .wc-proceed-to-checkout a.checkout-button',
		'.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button',
		'.woocommerce #respond input#submit.alt',
		'.woocommerce a.button.alt',
		'.woocommerce button.button.alt',
		'.woocommerce input.button.alt',
		'.woocommerce-account .woocommerce-MyAccount-navigation li.is-active',
		'.woocommerce .woocommerce-widget-layered-nav-dropdown__submit',
		'.woocommerce nav.woocommerce-pagination ul li span.current',
		'.latestPost-review-wrapper',
		'.latestPost .review-type-circle.latestPost-review-wrapper',
		'.woocommerce span.onsale',
		'.widget .widget_wp_review_tab .review-total-only.large-thumb',
		'#wp-calendar caption',
		'.single-subscribe .widget #wp-subscribe input.submit',
		'.error404 .article .sbutton',
		'.search .article .sbutton',
		'#sidebar .widget .tagcloud a:hover',
		'.f-widget .tagcloud a:hover',
		'.widget .wp_review_tab_widget_content ul.wp-review-tabs li.selected a::before',
		'.widget .wpt_widget_content ul.wpt-tabs li.selected a::before',
		'.tags a:hover',
		'#commentform input#submit',
		'#mtscontact_submit',
		'.widget #wp-subscribe input.consent-field:after',
		'.widget .sbutton',
		'.home-header #header.sticky-navigation-active',
		'.header-layout2 #primary-navigation li:before',
	);

	$css['global'][ citation_implode( $elements ) ]['background-color'] = $primary_color_scheme;

	// Background Hover Color.
	$elements = array(
		'.owl-prev:hover, .owl-next:hover',
		'.single-subscribe .widget #wp-subscribe input.submit:hover',
		'.error404 .article .sbutton:hover',
		'.search .article .sbutton:hover',
		'#commentform input#submit:hover',
		'#mtscontact_submit:hover',
		'.widget .sbutton:hover',
		'.widget #wp-subscribe input.submit:hover',
	);

	$css['global'][ citation_implode( $elements ) ]['background-color'] = $hover_color_scheme;

	// Background Color Important.
	$elements = array(
		'.widget .wpt_widget_content #tags-tab-content ul li a:hover ',
	);
	$css['global'][ citation_implode( $elements ) ]['background-color'] = $primary_color_scheme . '!important';

	// Border Color.
	$elements = array(
		'.page-numbers.current',
		'.pagination a:hover',
		'.tags a:hover',
		'.widget .wpt_widget_content #tags-tab-content ul li a',
		'#site-header .header-search .searchbox.searchbox-open .searchbox-input:focus',
		'.tagcloud a:hover',
		'#s:focus',
		'.mts-subscribe input[type="text"]:focus',
		'.widget_product_search .search-field:focus',
		'#wp-subscribe input.email-field:focus',
		'#wp-subscribe input.name-field:focus',
	);

	$css['global'][ citation_implode( $elements ) ]['border-color'] = $primary_color_scheme;

	// Border Color.
	$elements = array(
		'#wp-subscribe input.email-field:focus',
		'#wp-subscribe input.name-field:focus',
	);
	$css['global'][ citation_implode( $elements ) ]['border-color'] = $primary_color_scheme . '!important';

}

/**
 * Sidebar Position
 *
 * @param array $css Array of dynamic CSS.
 */
function citation_sidebar_position( &$css ) {

	// Sidebar position.
	$sidebar_position = citation_get_settings( 'mts_layout' );

	$sidebar_metabox_location = '';
	if ( is_page() || is_single() ) {
		$sidebar_metabox_location = get_post_meta( get_the_ID(), '_mts_sidebar_location', true );
	}

	if ( 'right' !== $sidebar_metabox_location && ( 'sclayout' === $sidebar_position || 'left' === $sidebar_metabox_location ) ) {
		$css['global']['.article']['float']                = 'right';
		$css['global']['.sidebar.c-4-12']['float']         = 'left';
		$css['global']['.sidebar.c-4-12']['padding-right'] = 0;

		if ( null !== citation_get_settings( 'mts_social_button_position' ) && 'floating' === citation_get_settings( 'mts_social_button_position' ) ) {

			$shareit_class = array(
				'.right .shareit.shareit-default.floating',
				'.right .shareit.standard.floating',
				'.right .shareit.shareit-circular.floating',
			);

			$css['global'][ citation_implode( $shareit_class ) ]['left']  = 'auto';
			$css['global'][ citation_implode( $shareit_class ) ]['right'] = '0px';

			$css['global'][ citation_implode( $shareit_class ) ]['margin-left']  = '0px';
			$css['global'][ citation_implode( $shareit_class ) ]['margin-right'] = '50px';
		}
	}
	if ( 'mts_nosidebar' == mts_custom_sidebar() ) {
		$css['global']['.single-full-header']['width'] = '100%';
	}
}

/**
 * Header
 *
 * @param array $css Array of dynamic CSS.
 */
function citation_header( &$css ) {

	$header_styles = citation_get_settings( 'header_styles' );
	// Header.
	$header_class = array(
		'#header',
	);
	citation_merge_value( $css['global'][ citation_implode( $header_class ) ], Citation_Sanitize::margin( citation_get_settings( 'header_margin' ) ) );
	citation_merge_value( $css['global'][ citation_implode( $header_class ) ], Citation_Sanitize::padding( citation_get_settings( 'header_padding' ) ) );

	// Header Border.
	$header_border = Citation_Sanitize::border( citation_get_settings( 'header_border' ) );
	$css['global'][ citation_implode( $header_class ) ][ $header_border['direction'] ] = $header_border ['value'];

	// Nav styling.
	// Nav color.
	$css['global']['#primary-navigation .navigation ul ul a']['color']            = Citation_Sanitize::color( citation_get_settings( 'main_navigation_dropdown_color' ) );
	$css['global']['#primary-navigation .navigation ul ul']['background']         = Citation_Sanitize::color( citation_get_settings( 'main_navigation_dropdown_background' ) );
	$css['global']['#primary-navigation .navigation ul ul li:hover > a']['color'] = Citation_Sanitize::color( citation_get_settings( 'main_navigation_dropdown_hover_color' ) );

	$buttons = citation_get_settings( 'header_buttons' );
	$i       = 0;
	if ( ! empty( $buttons ) && is_array( $buttons ) ) {
		foreach ( $buttons as $button ) {
			++$i;
			$css['global'][ '#site-header .header-button.button-' . $i . ' .button' ]['color']              = Citation_Sanitize::color( $button['button_text_color'] );
			$css['global'][ '#site-header .header-button.button-' . $i . ' .button' ]['background']         = Citation_Sanitize::color( $button['button_bg_color'] );
			$css['global'][ '#site-header .header-button.button-' . $i . ' .button:hover' ]['color']        = Citation_Sanitize::color( $button['button_text_hover_color'] );
			$css['global'][ '#site-header .header-button.button-' . $i . ' .button:hover' ]['background']   = Citation_Sanitize::color( $button['button_bg_hover_color'] );
			$css['global'][ '#site-header .header-button.button-' . $i . ' .button:hover' ]['border-color'] = Citation_Sanitize::color( $button['button_bg_hover_color'] );
			$css['global'][ '#site-header .header-button.button-' . $i . ' .button' ]['border-radius']      = Citation_Sanitize::size( $button['button_border_radius'] . 'px' );
			citation_merge_value( $css['global'][ '#site-header .header-button.button-' . $i ], Citation_Sanitize::margin( $button['header_button_margin'] ) );
			citation_merge_value( $css['global'][ '#site-header .header-button.button-' . $i . ' .button' ], Citation_Sanitize::padding( $button['header_button_padding'] ) );
			$button_border = Citation_Sanitize::border( $button['header_button_border'] );
			$css['global'][ '#site-header .header-button.button-' . $i . ' .button' ][ $button_border ['direction'] ] = $button_border ['value'];
		}
	}

	// Header Social icons.
	if ( ! empty( citation_get_settings( 'mts_header_social_share' ) ) && ! empty( citation_get_settings( 'header_social_icons' ) ) && is_array( citation_get_settings( 'header_social_icons' ) ) ) :
		$header_icons = citation_get_settings( 'header_social_icons' );
		foreach ( $header_icons as $header_icon ) :
			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ]['background-color']            = Citation_Sanitize::color( $header_icon['header_icon_bgcolor'] );
			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] . ':hover' ]['background-color'] = Citation_Sanitize::color( $header_icon['header_icon_hover_bgcolor'] );
			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ]['color']                       = Citation_Sanitize::color( $header_icon['header_icon_color'] );
			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] . ':hover' ]['color']            = Citation_Sanitize::color( $header_icon['header_icon_hover_color'] );
			citation_merge_value( $css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ], Citation_Sanitize::margin( $header_icon['header_icon_margin'] ) );
			citation_merge_value( $css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ], Citation_Sanitize::padding( $header_icon['header_icon_padding'] ) );
			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ]['border-radius'] = Citation_Sanitize::size( $header_icon['header_icon_border_radius'] . 'px' );
		endforeach;
	endif;

	// Header Ad.
	citation_merge_value( $css['global']['.widget-header, .small-header .widget-header'], Citation_Sanitize::margin( citation_get_settings( 'mts_header_adcode_margin' ) ) );

	// Ad-Blocker.
	$css['global']['.navigation-banner']['background'] = Citation_Sanitize::color( citation_get_settings( 'navigation_ad_background' ) );

	//Header Text
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'header_text_font' ) ) );

	//Layout 2 Header Nav Sections
	$header_layout_nav_class = array(
		'.header-layout2-bottom',
	);
	citation_merge_value( $css['global'][ citation_implode( $header_layout_nav_class ) ], Citation_Sanitize::background( citation_get_settings( 'header_layout2_nav_background' ) ) );
	citation_merge_value( $css['global'][ citation_implode( $header_layout_nav_class ) ], Citation_Sanitize::margin( citation_get_settings( 'header_layout2_nav_margin' ) ) );
	$header_layout2_nav_border = Citation_Sanitize::border( citation_get_settings( 'header_layout2_nav_border' ) );
	$css['global'][ citation_implode( $header_layout_nav_class ) ][ $header_layout2_nav_border ['direction'] ] = $header_layout2_nav_border ['value'];

	$header_text = citation_get_settings( 'header_text' );
	if ( empty( $header_text ) ) {
		$css['global']['.header-buttons']['flex'] = '1';
	}
	if ( empty( $buttons ) && ! is_array( $buttons ) && 'header-layout2' === $header_styles ) {
		$css['global']['.header-text']['margin-right'] = '0px';
	}
}

/**
 * Social Share Styling
 *
 * @param array $css Array of dynamic CSS.
 */
function citation_single_social_buttons( &$css ) {

	// Social share.
	$css['global']['.shareit.floating'] = Citation_Sanitize::background( citation_get_settings( 'social_styling_background' ) );
	citation_merge_value( $css['global']['.shareit.floating'], Citation_Sanitize::margin( citation_get_settings( 'social_styling_margin' ) ) );

	// Social share border.
	$social_border = Citation_Sanitize::border( citation_get_settings( 'social_styling_border' ) );
	$css['global']['.shareit.floating'][ $social_border ['direction'] ] = $social_border ['value'];

	$social_button_layout   = citation_get_settings( 'social_button_layout' );
	$social_button_position = citation_get_settings( 'social_floating_button_position' );
	if ( 'default' === $social_button_layout ) {
		$share_class = '.shareit.shareit-' . $social_button_layout . '.floating';
	} else {
		$share_class = '.shareit.' . $social_button_layout . '.floating';
	}
	if ( ! empty( $social_button_position ) && is_array( $social_button_position ) ) {
		foreach ( $social_button_position as $key => $position ) {
			$css['global'][ $share_class ][ $key ] = $position;
		}
	}
}

/**
 * Sidebar styling
 *
 * @param array $css Array of dynamic CSS.
 */
function citation_sidebar_styling( &$css ) {

	// Sidebar.
	citation_merge_value( $css['global']['.sidebar .widget'], Citation_Sanitize::background( citation_get_settings( 'sidebar_styling_background' ) ) );
	citation_merge_value( $css['global']['.sidebar .widget'], Citation_Sanitize::margin( citation_get_settings( 'sidebar_styling_margin' ) ) );
	citation_merge_value( $css['global']['.sidebar .widget'], Citation_Sanitize::padding( citation_get_settings( 'sidebar_styling_padding' ) ) );

	// Sidebar border.
	$sidebar_border = Citation_Sanitize::border( citation_get_settings( 'sidebar_styling_border' ) );
	$css['global']['.widget'][ $sidebar_border['direction'] ] = $sidebar_border['value'];

	// Sidebar title.
	$sidebar_title                   = '#sidebar .widget h3';
	$css['global'][ $sidebar_title ] = Citation_Sanitize::background( citation_get_settings( 'sidebar_title_styling_background' ) );
	citation_merge_value( $css['global'][ $sidebar_title ], Citation_Sanitize::padding( citation_get_settings( 'sidebar_title_styling_padding' ) ) );
	citation_merge_value( $css['global'][ $sidebar_title ], Citation_Sanitize::margin( citation_get_settings( 'sidebar_title_styling_margin' ) ) );

	// Sidebar Title border.
	$sidebar_title_border = Citation_Sanitize::border( citation_get_settings( 'widget_title_border' ) );
	$css['global'][ $sidebar_title ][ $sidebar_title_border['direction'] ] = $sidebar_title_border['value'];

}

/**
 * HomePage Sections CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function citation_homepage_settings( &$css ) {

	/**
	 * Featured Section
	 */
	$featured_button       = array(
		'.featured-button .button',
	);
	$featured_hover_button = array(
		'.featured-button .button:hover',
	);
	$css['global'][ citation_implode( $featured_button ) ]['color']            = Citation_Sanitize::color( citation_get_settings( 'featured_button_text_color' ) );
	$css['global'][ citation_implode( $featured_button ) ]['background']       = Citation_Sanitize::color( citation_get_settings( 'featured_button_bg_color' ) );
	$css['global'][ citation_implode( $featured_hover_button ) ]['color']      = Citation_Sanitize::color( citation_get_settings( 'featured_button_text_hover_color' ) );
	$css['global'][ citation_implode( $featured_hover_button ) ]['background'] = Citation_Sanitize::color( citation_get_settings( 'featured_button_bg_hover_color' ) );
	$css['global'][ citation_implode( $featured_button ) ]['border-radius']    = Citation_Sanitize::size( citation_get_settings( 'featured_button_border_radius' ) . 'px' );

	// Styling.
	citation_merge_value( $css['global']['.featured-section'], Citation_Sanitize::background( citation_get_settings( 'featured_background' ) ) );
	citation_merge_value( $css['global']['.featured-section'], Citation_Sanitize::margin( citation_get_settings( 'featured_margin' ) ) );
	citation_merge_value( $css['global']['.featured-section .container'], Citation_Sanitize::padding( citation_get_settings( 'featured_padding' ) ) );
	citation_merge_value( $css['global']['.featured-overlay'], Citation_Sanitize::background( citation_get_settings( 'featured_overlay' ) ) );

	// Typography.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'featured_title_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'featured_content_font' ) ) );

	/**
	 * Services Section
	 */
	$i        = 0;
	$services = citation_get_settings( 'services_list' );

	// Styling.
	citation_merge_value( $css['global']['.services-section'], Citation_Sanitize::background( citation_get_settings( 'services_background' ) ) );

	if ( $services && is_array( $services ) ) {
		foreach ( $services as $service ) {
			++$i;
			citation_merge_value( $css['global'][ '.services-section li.service-' . $i . ' .service-icon .fa' ], Citation_Sanitize::background( $service['service_icon_color'] ) );
			$css['global'][ '.services-section li.service-' . $i . ' .service-content h3' ]['color'] = Citation_Sanitize::color( $service['service_title_color'] );
			$css['global'][ '.services-section li.service-' . $i . ' .service-content p' ]['color']  = Citation_Sanitize::color( $service['service_text_color'] );
			$css['global'][ '.services-section li.service-' . $i . ' .button' ]['color']             = Citation_Sanitize::color( $service['service_button_color'] );
			$css['global'][ '.services-section li.service-' . $i . ' .button' ]['background']        = Citation_Sanitize::color( $service['service_button_bg'] );
			$css['global'][ '.services-section li.service-' . $i . ' .button:hover' ]['color']       = Citation_Sanitize::color( $service['service_button_hover_color'] );
			$css['global'][ '.services-section li.service-' . $i . ' .button:hover' ]['background']  = Citation_Sanitize::color( $service['service_button_hover_bg'] );
		}
	}

	citation_merge_value( $css['global']['.services-section'], Citation_Sanitize::margin( citation_get_settings( 'services_margin' ) ) );
	citation_merge_value( $css['global']['.services-section'], Citation_Sanitize::padding( citation_get_settings( 'services_padding' ) ) );

	// Typography.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'services_heading_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'services_subheading_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'services_list_title_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'services_list_text_font' ) ) );

	/**
	 * Locations Section
	 */
	$locations_button       = array(
		'.locations-button .button',
	);
	$locations_hover_button = array(
		'.locations-button .button:hover',
	);
	$css['global'][ citation_implode( $locations_button ) ]['color']            = Citation_Sanitize::color( citation_get_settings( 'locations_button_color' ) );
	$css['global'][ citation_implode( $locations_button ) ]['background']       = Citation_Sanitize::color( citation_get_settings( 'locations_button_bg' ) );
	$css['global'][ citation_implode( $locations_hover_button ) ]['color']      = Citation_Sanitize::color( citation_get_settings( 'locations_button_hover_color' ) );
	$css['global'][ citation_implode( $locations_hover_button ) ]['background'] = Citation_Sanitize::color( citation_get_settings( 'locations_button_hover_bg' ) );

	// Styling.
	citation_merge_value( $css['global']['.locations-section'], Citation_Sanitize::background( citation_get_settings( 'locations_background' ) ) );
	citation_merge_value( $css['global']['.locations-section'], Citation_Sanitize::margin( citation_get_settings( 'locations_margin' ) ) );
	citation_merge_value( $css['global']['.locations-section'], Citation_Sanitize::padding( citation_get_settings( 'locations_padding' ) ) );

	// Typography.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'locations_heading_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'locations_subheading_font' ) ) );

	/**
	 * Features Section
	 */
	$i        = 0;
	$features = citation_get_settings( 'features_list' );

	// Styling.
	citation_merge_value( $css['global']['.features-section'], Citation_Sanitize::background( citation_get_settings( 'features_background' ) ) );

	if ( $features && is_array( $features ) ) {
		foreach ( $features as $feature ) {
			++$i;
			citation_merge_value( $css['global'][ '.features-section li.feature-' . $i . ' .feature-icon .fa' ], Citation_Sanitize::background( $feature['feature_icon_color'] ) );
			$css['global'][ '.features-section li.feature-' . $i . ' .feature-content h3' ]['color'] = Citation_Sanitize::color( $feature['feature_title_color'] );
			$css['global'][ '.features-section li.feature-' . $i . ' .feature-content p' ]['color']  = Citation_Sanitize::color( $feature['feature_text_color'] );
		}
	}

	citation_merge_value( $css['global']['.features-section'], Citation_Sanitize::margin( citation_get_settings( 'features_margin' ) ) );
	citation_merge_value( $css['global']['.features-section'], Citation_Sanitize::padding( citation_get_settings( 'features_padding' ) ) );

	// Typography.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'features_heading_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'features_subheading_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'features_list_title_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'features_list_text_font' ) ) );

	/**
	 * Advanced Feature Section
	 */
	$count                = 0;
	$features             = citation_get_settings( 'advanced_feature_list' );
	$primary_color_scheme = Citation_Sanitize::color( citation_get_settings( 'primary_color_scheme' ) );

	if ( $features && is_array( $features ) ) {

		foreach ( $features as $feature ) {

			++$count;

			if ( 'left' === $feature['advanced_feature_alignment'] ) {
				foreach ( $feature['img_position_left'] as $key => $position ) {
					$css['global'][ '.left.advanced-feature-' . $count . ' .advanced-feature-img' ][ $key ] = $position;
				}
			} else {
				foreach ( $feature['img_position_right'] as $key => $position ) {
					$css['global'][ '.right.advanced-feature-' . $count . ' .advanced-feature-img' ][ $key ] = $position;
				}
			}

			citation_merge_value( $css['global'][ '.advanced-feature-section li.advanced-feature-' . $count . ' .advanced-content-area' ], Citation_Sanitize::padding( $feature['advanced_feature_content_padding'] ) );
			//Buttons
			$css['global'][ '.advanced-feature-section li.advanced-feature-' . $count . ' .button' ]['color']            = Citation_Sanitize::color( $feature['advanced_feature_button_color'] );
			$css['global'][ '.advanced-feature-section li.advanced-feature-' . $count . ' .button' ]['background']       = Citation_Sanitize::color( $feature['advanced_feature_button_bg'] );
			$css['global'][ '.advanced-feature-section li.advanced-feature-' . $count . ' .button:hover' ]['color']      = Citation_Sanitize::color( $feature['advanced_feature_button_hover_color'] );
			$css['global'][ '.advanced-feature-section li.advanced-feature-' . $count . ' .button:hover' ]['background'] = Citation_Sanitize::color( $feature['advanced_feature_button_hover_bg'] );
			citation_merge_value( $css['global'][ '.advanced-feature-section li.advanced-feature-' . $count ], Citation_Sanitize::margin( $feature['advanced_feature_margin'] ) );
			citation_merge_value( $css['global'][ '.advanced-feature-section li.advanced-feature-' . $count ], Citation_Sanitize::padding( $feature['advanced_feature_padding'] ) );

		}
	}

	// Styling.
	citation_merge_value( $css['global']['.advanced-feature-section'], Citation_Sanitize::background( citation_get_settings( 'advanced_feature_background' ) ) );

	// Typography.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'advanced_feature_title_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'advanced_feature_content_font' ) ) );

	/**
	 * CTA Section
	 */
	$cta_button       = array(
		'.cta-button .button',
	);
	$cta_hover_button = array(
		'.cta-button .button:hover',
	);
	$css['global'][ citation_implode( $cta_button ) ]['color']            = Citation_Sanitize::color( citation_get_settings( 'cta_button_color' ) );
	$css['global'][ citation_implode( $cta_button ) ]['background']       = Citation_Sanitize::color( citation_get_settings( 'cta_button_bg' ) );
	$css['global'][ citation_implode( $cta_hover_button ) ]['color']      = Citation_Sanitize::color( citation_get_settings( 'cta_button_hover_color' ) );
	$css['global'][ citation_implode( $cta_hover_button ) ]['background'] = Citation_Sanitize::color( citation_get_settings( 'cta_button_hover_bg' ) );

	// Styling.
	citation_merge_value( $css['global']['.cta-section'], Citation_Sanitize::background( citation_get_settings( 'cta_background' ) ) );
	citation_merge_value( $css['global']['.cta-section'], Citation_Sanitize::margin( citation_get_settings( 'cta_margin' ) ) );
	citation_merge_value( $css['global']['.cta-section'], Citation_Sanitize::padding( citation_get_settings( 'cta_padding' ) ) );

	// Typography.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'cta_title_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'cta_text_font' ) ) );

	/**
	 * Custom HTML
	 */

	// Margin and Padding.
	citation_merge_value( $css['global']['.html-section'], Citation_Sanitize::margin( citation_get_settings( 'html_margin' ) ) );
	citation_merge_value( $css['global']['.html-section'], Citation_Sanitize::padding( citation_get_settings( 'html_padding' ) ) );

}

/**
 * Pages Titles CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function citation_pages_title( &$css ) {

	// Background.
	$css['global']['.pages-title-section'] = Citation_Sanitize::background( citation_get_settings( 'pages_title_background' ) );

	// Padding and Margin.
	citation_merge_value( $css['global']['.pages-title-section'], Citation_Sanitize::padding( citation_get_settings( 'pages_title_padding' ) ) );
	citation_merge_value( $css['global']['.pages-title-section'], Citation_Sanitize::margin( citation_get_settings( 'pages_title_margin' ) ) );

	// Typography.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'pages_title_font' ) ) );
	// Breadcrumbs font.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'breadcrumb_font' ) ) );

}

/**
 * Layout CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function citation_post_layouts( &$css ) {

	// Post Layouts.
	$features = citation_get_settings( 'featured_categories' );
	foreach ( $features as $feature ) :

		if ( ! isset( $feature['unique_id'] ) ) {
			continue;
		}

		$category     = $feature['mts_featured_category'];
		$posts_layout = isset( $feature['blog_layout'] ) ? $feature['blog_layout'] : 'layout-default';
		$unique_id    = $feature['unique_id'];

		if ( 'layout-default' === $posts_layout ) :
			$posts_layout = 'default';
		endif;

		// Section title align.
		$post_title_align = citation_get_settings( 'post_title_alignment_' . $unique_id );

		// Post area.
		$cat_class = 'cat-latest';
		if ( 'latest' !== $category ) {
			$category  = get_term_by( 'slug', $category, 'category' );
			$cat_class = sanitize_key( $category->name );
		}

		$title_class = '.title-container.title-id-' . $unique_id . ' h3';

		$css['global'][ $title_class ] = Citation_Sanitize::background( citation_get_settings( 'featured_category_title_background_' . $unique_id ) );
		citation_merge_value( $css['global'][ $title_class ], Citation_Sanitize::margin( citation_get_settings( 'featured_category_title_margin_' . $unique_id ) ) );
		citation_merge_value( $css['global'][ $title_class ], Citation_Sanitize::padding( citation_get_settings( 'featured_category_title_padding_' . $unique_id ) ) );
		// Section title border.
		$post_title_border = Citation_Sanitize::border( citation_get_settings( 'post_title_border_' . $unique_id ) );
		$css['global'][ $title_class ][ $post_title_border['direction'] ] = $post_title_border['value'];

		// Title alignment.
		$align_class = '.title-container.title-id-' . $unique_id;
		if ( 'center' === $post_title_align ) :
			$css['global'][ $align_class ]['text-align'] = 'center';
		elseif ( 'right' === $post_title_align ) :
			$css['global'][ $align_class ]['text-align'] = 'right';
		endif;

		citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'featured_category_title_font_' . $unique_id ) ) );

		if ( 'layout-default' === $posts_layout ) {
			$post_class = '.layout-' . $unique_id . '.default-container';
		} else {
			$post_class = '.layout-' . $unique_id;
		}

		// Post border.
		$post_border = Citation_Sanitize::border( citation_get_settings( 'post_border_' . $unique_id ) );
		$css['global'][ $post_class ][ $post_border['direction'] ] = $post_border['value'];

		/**
		 * Meta info
		 */
		citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'meta_info_font_' . $unique_id ) ) );
		citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'readmore_font_' . $unique_id ) ) );

		citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'post_title_font_' . $unique_id ) ) );
		citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'post_excerpt_font_' . $unique_id ) ) );
		$readmore_border = Citation_Sanitize::border( citation_get_settings( 'readmore_border_' . $unique_id ) );
		$css['global'][ $post_class . ' .readMore a' ][ $readmore_border ['direction'] ] = $readmore_border['value'];
		//Color Options
		$css['global'][ $post_class . ' .readMore a' ]['background']         = Citation_Sanitize::color( citation_get_settings( 'readmore_bg_color_' . $unique_id ) );
		$css['global'][ $post_class . ' .readMore a:hover' ]['background']   = Citation_Sanitize::color( citation_get_settings( 'readmore_bg_hover_color_' . $unique_id ) );
		$css['global'][ $post_class . ' .readMore a:hover' ]['color']        = Citation_Sanitize::color( citation_get_settings( 'readmore_hover_color_' . $unique_id ) );
		$css['global'][ $post_class . ' .readMore a:hover' ]['border-color'] = Citation_Sanitize::color( citation_get_settings( 'readmore_border_hover_color_' . $unique_id ) );

		// Border.
		$meta_info_border = Citation_Sanitize::border( citation_get_settings( 'meta_info_border_' . $unique_id ) );
		$css['global'][ '.layout-' . $unique_id . ' .latestPost .post-info' ][ $meta_info_border['direction'] ] = $meta_info_border['value'];

		// All Posts Margin and Padding.
		citation_merge_value( $css['global'][ $post_class ], Citation_Sanitize::margin( citation_get_settings( 'post_margin_' . $unique_id ) ) );
		citation_merge_value( $css['global'][ $post_class ], Citation_Sanitize::padding( citation_get_settings( 'post_padding_' . $unique_id ) ) );

	endforeach;
}

/**
 * Pagination
 *
 * @param array $css Array of dynamic CSS.
 */
function citation_post_pagination( &$css ) {

	// Pagination Active class.
	$pagination_class_active = array(
		'.pace .pace-progress',
		'.page-numbers.current',
		'.pagination a:hover',
		'.single .pagination > .current .currenttext',
		'#mobile-menu-wrapper ul li a:hover',
		'#load-posts a:hover',
	);
	$pagination_class        = array(
		'.pagination a',
		'#load-posts a',
		'.pagination .page-numbers.dots',
		'.page-numbers.current',
	);
	if ( '2' !== citation_get_settings( 'mts_pagenavigation_type' ) ) {
		$css['global'][ citation_implode( $pagination_class ) ]['background-color']        = Citation_Sanitize::color( citation_get_settings( 'mts_pagenavigation_bgcolor' ) );
		$css['global'][ citation_implode( $pagination_class_active ) ]['background-color'] = Citation_Sanitize::color( citation_get_settings( 'mts_pagenavigation_hover_bgcolor' ) );
		$css['global'][ citation_implode( $pagination_class ) ]['color']                   = Citation_Sanitize::color( citation_get_settings( 'mts_pagenavigation_color' ) );
		$css['global'][ citation_implode( $pagination_class_active ) ]['color']            = Citation_Sanitize::color( citation_get_settings( 'mts_pagenavigation_hover_color' ) );
		$css['global'][ citation_implode( $pagination_class_active ) ]['border-color']     = Citation_Sanitize::color( citation_get_settings( 'mts_pagenavigation_hover_bgcolor' ) );
		citation_merge_value( $css['global'][ citation_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Citation_Sanitize::margin( citation_get_settings( 'mts_pagenavigation_margin' ) ) );
		citation_merge_value( $css['global'][ citation_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Citation_Sanitize::padding( citation_get_settings( 'mts_pagenavigation_padding' ) ) );
		$css['global'][ citation_implode( $pagination_class ) ]['min-width']          = Citation_Sanitize::size( citation_get_settings( 'mts_pagenavigation_width' ) . 'px' );
		$css['global'][ citation_implode( $pagination_class_active ) ]['min-width']   = Citation_Sanitize::size( citation_get_settings( 'mts_pagenavigation_width' ) . 'px' );
		$css['global'][ citation_implode( $pagination_class ) ]['line-height']        = Citation_Sanitize::size( citation_get_settings( 'mts_pagenavigation_height' ) . 'px' );
		$css['global'][ citation_implode( $pagination_class_active ) ]['line-height'] = Citation_Sanitize::size( citation_get_settings( 'mts_pagenavigation_height' ) . 'px' );
		// Pagination border.
		$pagination_border = Citation_Sanitize::border( citation_get_settings( 'pagenavigation_border' ) );
		$css['global'][ citation_implode( $pagination_class ) ][ $pagination_border ['direction'] ] = $pagination_border ['value'];
		$pagination_hover_border = Citation_Sanitize::border( citation_get_settings( 'pagenavigation_hover_border' ) );
		$css['global'][ citation_implode( $pagination_class_active ) ][ $pagination_hover_border ['direction'] ] = $pagination_hover_border ['value'];
		$css['global'][ citation_implode( $pagination_class ) ]['border-radius']                                 = Citation_Sanitize::size( citation_get_settings( 'mts_pagenavigation_border_radius' ) . 'px' );
		$css['global'][ citation_implode( $pagination_class_active ) ]['border-radius']                          = Citation_Sanitize::size( citation_get_settings( 'mts_pagenavigation_border_radius' ) . 'px' );
	} else {
		$css['global'][ citation_implode( $pagination_class ) ]['background-color']        = Citation_Sanitize::color( citation_get_settings( 'load_more_bgcolor' ) );
		$css['global'][ citation_implode( $pagination_class_active ) ]['background-color'] = Citation_Sanitize::color( citation_get_settings( 'load_more_hover_bgcolor' ) );
		$css['global'][ citation_implode( $pagination_class ) ]['color']                   = Citation_Sanitize::color( citation_get_settings( 'load_more_color' ) );
		$css['global'][ citation_implode( $pagination_class_active ) ]['color']            = Citation_Sanitize::color( citation_get_settings( 'load_more_hover_color' ) );
		citation_merge_value( $css['global'][ citation_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Citation_Sanitize::padding( citation_get_settings( 'load_more_padding' ) ) );
		citation_merge_value( $css['global'][ citation_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Citation_Sanitize::margin( citation_get_settings( 'load_more_margin' ) ) );
		$css['global'][ citation_implode( $pagination_class_active ) ]['border-color'] = Citation_Sanitize::color( citation_get_settings( 'load_more_hover_bgcolor' ) );
		// Load More border.
		$load_more_border = Citation_Sanitize::border( citation_get_settings( 'load_more_border' ) );
		$css['global'][ citation_implode( $pagination_class ) ][ $load_more_border ['direction'] ] = $load_more_border ['value'];
		$css['global'][ citation_implode( $pagination_class ) ]['border-radius']                   = Citation_Sanitize::size( citation_get_settings( 'load_more_border_radius' ) . 'px' );
		$css['global'][ citation_implode( $pagination_class_active ) ]['border-radius']            = Citation_Sanitize::size( citation_get_settings( 'load_more_border_radius' ) . 'px' );
	}

	// Load more Alignment.
	$load_more_align = citation_get_settings( 'load_more_alignment' );
	if ( 'left' === $load_more_align ) :
		$css['global']['#load-posts']['text-align'] = 'left';
	elseif ( 'right' === $load_more_align ) :
		$css['global']['#load-posts']['text-align'] = 'right';
	elseif ( 'full' === $load_more_align ) :
		$css['global']['#load-posts a']['width'] = '100%';
	endif;
}

/**
 * Single
 *
 * @param array $css Array of dynamic CSS.
 */
function citation_single( &$css ) {

	// Single Page auto padding.
	$single_padding = Citation_Sanitize::padding( citation_get_settings( 'mts_single_styling_padding' ) );

	$css['global']['.single-featured-image']['margin-top']   = '-' . $single_padding['padding-top'];
	$css['global']['.single-featured-image']['margin-right'] = '-' . $single_padding['padding-right'];
	$css['global']['.single-featured-image']['margin-left']  = '-' . $single_padding['padding-left'];

	// Single, Page and 404 Page Background.
	$page_classes = array(
		'.single_post',
		'.page .article',
		'.error404 .article',
	);

	$css['global'][ citation_implode( $page_classes ) ] = Citation_Sanitize::background( citation_get_settings( 'single_background' ) );

	// Margin, Padding, Border and Box Shadow.
	citation_merge_value( $css['global'][ citation_implode( $page_classes ) ], Citation_Sanitize::margin( citation_get_settings( 'mts_single_styling_margin' ) ) );
	citation_merge_value( $css['global'][ citation_implode( $page_classes ) ], Citation_Sanitize::padding( citation_get_settings( 'mts_single_styling_padding' ) ) );

	// Single border.
	$single_border = Citation_Sanitize::border( citation_get_settings( 'single_styling_border' ) );
	$css['global']['.article'][ $single_border ['direction'] ] = $single_border ['value'];

	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'mts_single_category_meta_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'mts_single_meta_info_font' ) ) );

	// Tags.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'tags_font' ) ) );
	$css['global']['.tags'] = Citation_Sanitize::background( citation_get_settings( 'tags_background' ) );
	citation_merge_value( $css['global']['.tags'], Citation_Sanitize::margin( citation_get_settings( 'tags_margin' ) ) );
	citation_merge_value( $css['global']['.tags'], Citation_Sanitize::padding( citation_get_settings( 'tags_padding' ) ) );
	$tags_border = Citation_Sanitize::border( citation_get_settings( 'tags_border' ) );
	$css['global']['.tags'][ $tags_border ['direction'] ] = $tags_border ['value'];

	// Related Posts.
	$css['global']['.related-posts'] = Citation_Sanitize::background( citation_get_settings( 'related_posts_background' ) );

	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'related_posts_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'related_posts_meta_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'related_posts_text_font' ) ) );
	$css['global']['.related-posts .thecategory a']['color'] = Citation_Sanitize::color( citation_get_settings( 'related_posts_categories_color' ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'related_readmore_font' ) ) );
	$css['global']['.related-posts .readMore a:hover']['color'] = Citation_Sanitize::color( citation_get_settings( 'related_readmore_hover_color' ) );

	citation_merge_value( $css['global']['.related-posts'], Citation_Sanitize::margin( citation_get_settings( 'related_posts_margin' ) ) );
	citation_merge_value( $css['global']['.related-posts'], Citation_Sanitize::padding( citation_get_settings( 'related_posts_padding' ) ) );

	$related_posts_border = Citation_Sanitize::border( citation_get_settings( 'related_posts_border' ) );
	$css['global']['.related-posts'][ $related_posts_border ['direction'] ] = $related_posts_border ['value'];

	// Related Posts articles.
	$css['global']['.related-posts article'] = Citation_Sanitize::background( citation_get_settings( 'related_article_background' ) );
	citation_merge_value( $css['global']['.related-posts article'], Citation_Sanitize::padding( citation_get_settings( 'related_article_padding' ) ) );

	// Subscribe Box.
	$css['global']['.single-subscribe .widget.wp_subscribe'] = Citation_Sanitize::background( citation_get_settings( 'single_subscribe_background' ) );
	citation_merge_value( $css['global']['.single-subscribe .widget.wp_subscribe'], Citation_Sanitize::margin( citation_get_settings( 'single_subscribe_margin' ) ) );
	citation_merge_value( $css['global']['.single-subscribe .widget.wp_subscribe'], Citation_Sanitize::padding( citation_get_settings( 'single_subscribe_padding' ) ) );
	$css['global']['.single-subscribe .widget.wp_subscribe']['border-radius'] = Citation_Sanitize::size( citation_get_settings( 'single_subscribe_border_radius' ) . 'px' );

	// Subscribe border.
	$subscribe_border = Citation_Sanitize::border( citation_get_settings( 'single_subscribe_border' ) );
	$css['global']['.single-subscribe .widget.wp_subscribe'][ $subscribe_border ['direction'] ] = $subscribe_border ['value'];

	// Subscribe Box Input fields.
	$subscribe_input_class = array(
		'.single-subscribe #wp-subscribe input.email-field',
		'.single-subscribe #wp-subscribe input.name-field',
	);
	$css['global'][ citation_implode( $subscribe_input_class ) ]['background-color'] = Citation_Sanitize::color( citation_get_settings( 'single_subscribe_input_background' ) );

	$css['global'][ citation_implode( $subscribe_input_class ) ]['height'] = Citation_Sanitize::size( citation_get_settings( 'single_subscribe_input_height' ) . 'px' );

	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['height'] = Citation_Sanitize::size( citation_get_settings( 'single_subscribe_input_height' ) . 'px' );

	$css['global'][ citation_implode( $subscribe_input_class ) ]['border-radius'] = Citation_Sanitize::size( citation_get_settings( 'single_subscribe_input_border_radius' ) . 'px' );

	// Subscribe Box Input border.
	$subscribe_box_input_border = Citation_Sanitize::border( citation_get_settings( 'single_subscribe_input_border' ) );
	$css['global'][ citation_implode( $subscribe_input_class ) ][ $subscribe_box_input_border ['direction'] ] = $subscribe_box_input_border ['value'];

	// Subscribe Box Submit button.
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['background']    = Citation_Sanitize::color( citation_get_settings( 'single_subscribe_submit_backgroud' ) );
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['border-radius'] = Citation_Sanitize::size( citation_get_settings( 'single_subscribe_submit_border_radius' ) . 'px' );

	// Subscribe Box Submit border.
	$subscribe_box_submit_border = Citation_Sanitize::border( citation_get_settings( 'single_subscribe_submit_border' ) );
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit'][ $subscribe_box_submit_border ['direction'] ] = $subscribe_box_submit_border ['value'];

	citation_merge_value( $css['global']['.single-subscribe .widget #wp-subscribe input.submit'], Citation_Sanitize::padding( citation_get_settings( 'single_subscribe_submit_padding' ) ) );

	// Author Box.
	$css['global']['.postauthor'] = Citation_Sanitize::background( citation_get_settings( 'authorbox_background' ) );

	citation_merge_value( $css['global']['.postauthor'], Citation_Sanitize::margin( citation_get_settings( 'authorbox_margin' ) ) );

	citation_merge_value( $css['global']['.postauthor'], Citation_Sanitize::padding( citation_get_settings( 'authorbox_padding' ) ) );

	$css['global']['.postauthor']['border-radius'] = Citation_Sanitize::size( citation_get_settings( 'authorbox_border_radius' ) . 'px' );

	$authorbox_border = Citation_Sanitize::border( citation_get_settings( 'authorbox_border' ) );
	$css['global']['.postauthor'][ $authorbox_border ['direction'] ] = $authorbox_border ['value'];

	// Author image.
	citation_merge_value( $css['global']['.postauthor img'], Citation_Sanitize::margin( citation_get_settings( 'single_author_image_margin' ) ) );

	$css['global']['.postauthor img']['border-radius'] = Citation_Sanitize::size( citation_get_settings( 'single_author_image_border_radius' ) . 'px' );

	// Single Page titles Styling.
	$titles_align = citation_get_settings( 'single_title_alignment' );

	$titles_align_class = array(
		'.comment-title',
		'#respond',
		'.related-posts-title',
	);
	$titles_class       = array(
		'#respond h3',
		'#respond h4',
		'.total-comments',
		'.related-posts h4',
	);

	$css['global'][ citation_implode( $titles_class ) ] = Citation_Sanitize::background( citation_get_settings( 'single_title_background' ) );
	citation_merge_value( $css['global'][ citation_implode( $titles_class ) ], Citation_Sanitize::padding( citation_get_settings( 'single_title_padding' ) ) );
	// Single title border.
	$single_titles_border = Citation_Sanitize::border( citation_get_settings( 'single_title_border' ) );
	$css['global'][ citation_implode( $titles_class ) ][ $single_titles_border ['direction'] ] = $single_titles_border ['value'];

	if ( 'left' === $titles_align ) :
		$css['global'][ citation_implode( $titles_class ) ]['display'] = 'inline-block';
	elseif ( 'center' === $titles_align ) :
		$css['global'][ citation_implode( $titles_align_class ) ]['text-align'] = 'center';
		$css['global'][ citation_implode( $titles_class ) ]['display']          = 'inline-block';
	elseif ( 'right' === $titles_align ) :
		$css['global'][ citation_implode( $titles_align_class ) ]['text-align'] = 'right';
		$css['global'][ citation_implode( $titles_class ) ]['display']          = 'inline-block';
	endif;

	// Comments.
	$css['global']['ol.commentlist'] = Citation_Sanitize::background( citation_get_settings( 'comments_background' ) );
	// Margin and Padding.
	citation_merge_value( $css['global']['ol.commentlist'], Citation_Sanitize::margin( citation_get_settings( 'comments_margin' ) ) );
	citation_merge_value( $css['global']['ol.commentlist'], Citation_Sanitize::padding( citation_get_settings( 'comments_padding' ) ) );
	citation_merge_value( $css['global']['#comments .avatar'], Citation_Sanitize::margin( citation_get_settings( 'comments_list_image_margin' ) ) );
		citation_merge_value( $css['global']['#commentsAdd'], Citation_Sanitize::margin( citation_get_settings( 'commentsAdd_margin' ) ) );

	// Author Comment.
	citation_merge_value( $css['global']['#comments li.bypostauthor'], Citation_Sanitize::padding( citation_get_settings( 'comments_list_author_padding' ) ) );
	$css['global']['#comments li.bypostauthor']['background-color'] = Citation_Sanitize::color( citation_get_settings( 'author_comment_bg' ) );

	// Comment list.
	$css['global']['#comments .avatar']['border-radius'] = Citation_Sanitize::size( citation_get_settings( 'comments_list_image_border_radius' ) . 'px' );

	// Typography.
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'comments_title_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'comments_meta_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'comments_text_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'comments_reply_font' ) ) );
}

/**
 * Copyrights
 *
 * @param array $css Array of dynamic CSS.
 */
function citation_copyrights( &$css ) {

	// copyrights border.
	$copyrights_border = Citation_Sanitize::border( citation_get_settings( 'copyrights_border' ) );
	$css['global']['.copyrights'][ $copyrights_border ['direction'] ] = $copyrights_border ['value'];
	citation_merge_value( $css['global']['.copyrights'], Citation_Sanitize::margin( citation_get_settings( 'mts_copyrights_margin' ) ) );
	citation_merge_value( $css['global']['.copyrights'], Citation_Sanitize::padding( citation_get_settings( 'mts_copyrights_padding' ) ) );
}

/**
 * Footer
 *
 * @param array $css Array of dynamic CSS.
 */
function citation_footer( &$css ) {

	// Footer.
	citation_merge_value( $css['global']['#site-footer'], Citation_Sanitize::margin( citation_get_settings( 'mts_top_footer_margin' ) ) );
	citation_merge_value( $css['global']['#site-footer'], Citation_Sanitize::padding( citation_get_settings( 'mts_top_footer_padding' ) ) );
	$mts_top_footer_border = Citation_Sanitize::border( citation_get_settings( 'mts_top_footer_border' ) );
		$css['global']['#site-footer'][ $mts_top_footer_border ['direction'] ] = $mts_top_footer_border ['value'];

	// footer Nav menu item.
	citation_merge_value( $css['global']['.footer-nav-container li a'], citation_Sanitize::margin( citation_get_settings( 'footer_menu_item_margin' ) ) );
	citation_merge_value( $css['global']['.footer-nav-container .footer-separator'], citation_Sanitize::margin( citation_get_settings( 'footer_nav_separator_margin' ) ) );
	$css['global']['.footer-nav-container .footer-separator']['color'] = citation_Sanitize::color( citation_get_settings( 'footer_nav_separator_color' ) );

	//Social & Nav Container
	citation_merge_value( $css['global']['.footer-logo-nav-section'], Citation_Sanitize::background( citation_get_settings( 'footer_logo_nav_background' ) ) );
	citation_merge_value( $css['global']['.footer-logo-nav-section .container'], Citation_Sanitize::margin( citation_get_settings( 'footer_logo_nav_margin' ) ) );
	citation_merge_value( $css['global']['.footer-logo-nav-section .container'], Citation_Sanitize::padding( citation_get_settings( 'footer_logo_nav_padding' ) ) );

	// Top & Bottom Primary Navigation Border.
	$footer_nav_social = array(
		'.footer-logo-nav-section',
	);
	//Border
	$footer_nav_social_border = Citation_Sanitize::border( citation_get_settings( 'footer_logo_nav_border' ) );
	$css['global'][ citation_implode( $footer_nav_social ) ][ $footer_nav_social_border ['direction'] ] = $footer_nav_social_border ['value'];

	$footer_logo_nav_position = citation_get_settings( 'footer_logo_nav_position' );
	if ( 'left' === $footer_logo_nav_position ) :
		$css['global']['.footer-logo-nav-section .container']['flex-direction'] = 'row-reverse';
		$css['global']['.footer-nav-section']['justify-content']                = 'flex-start';
		$css['global']['.footer-logo-wrap']['text-align']                       = 'right';
		$css['@media screen and (max-width: 600px)']['.footer-logo-nav-section .container']['flex-direction'] = 'column-reverse';
	endif;

}

/**
 * Archive
 *
 * @param array $css Array of dynamic CSS.
 */
function citation_archive_post( &$css ) {

	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'archive_post_title_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'archive_post_excerpt_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'archive_meta_info_font' ) ) );
	citation_map_css_selectors( $css['global'], Citation_Sanitize::typography( citation_get_settings( 'archive_readmore_font' ) ) );
	$archive_readmore = array(
		'.archive .latestPost .readMore a:hover',
		'.search .latestPost .readMore a:hover',
	);
	$css['global'][ citation_implode( $archive_readmore ) ]['color'] = Citation_Sanitize::color( citation_get_settings( 'archive_readmore_hover_color' ) );

}

/**
 * Misc
 *
 * @param array $css Array of dynamic CSS.
 */
function citation_misc_css( &$css ) {

	// Nav hover color position.
	$padding        = Citation_Sanitize::padding( citation_get_settings( 'header_padding' ) );
	$padding_bottom = (int) $padding['padding-bottom'];

	// Show Logo.
	$show_logo = citation_get_settings( 'hide_logo' );

	if ( 0 === $show_logo ) {
		$css['global']['.logo-wrap']['display'] = 'none';
	}

	// Back to top.
	$css['global']['#move-to-top']              = Citation_Sanitize::background( citation_get_settings( 'top_button_background' ) );
	$css['global']['#move-to-top:hover::after'] = Citation_Sanitize::background( citation_get_settings( 'top_button_background_hover' ) );

	// Border.
	$top_button_border = Citation_Sanitize::border( citation_get_settings( 'top_button_border' ) );
	$css['global']['#move-to-top'][ $top_button_border ['direction'] ] = $top_button_border ['value'];
	// Font-size, Padding and Position.
	$css['global']['#move-to-top .fa']['font-size'] = Citation_Sanitize::size( citation_get_settings( 'top_button_font_size' ) . 'px' );
	citation_merge_value( $css['global']['#move-to-top'], Citation_Sanitize::padding( citation_get_settings( 'top_button_padding' ) ) );
	$top_button_position = citation_get_settings( 'top_button_position' );
	foreach ( $top_button_position as $key => $position ) {
		$css['global']['#move-to-top'][ $key ] = $position;
	}
	// Border-radius.
	$css['global']['#move-to-top']['border-radius']        = Citation_Sanitize::size( citation_get_settings( 'top_button_border_radius' ) . 'px' );
	$css['global']['#move-to-top::after']['border-radius'] = Citation_Sanitize::size( citation_get_settings( 'top_button_border_radius' ) . 'px' );
	// Colors.
	$css['global']['#move-to-top']['color']       = Citation_Sanitize::color( citation_get_settings( 'top_button_color' ) );
	$css['global']['#move-to-top:hover']['color'] = Citation_Sanitize::color( citation_get_settings( 'top_button_color_hover' ) );

	// Full width Related Posts.
	if ( 'full' === citation_get_settings( 'related_posts_position' ) ) {
		$css['global']['.single .article']['margin-bottom'] = '0px';
	}

	$widgets_margin = Citation_Sanitize::padding( citation_get_settings( 'sidebar_styling_padding' ) );
	$elements       = array(
		'.sidebar .widget.instagram-widget-wrapper .instagram-posts',
	);
	$css['global'][ citation_implode( $elements ) ]['margin-left']  = '-' . $widgets_margin['padding-left'];
	$css['global'][ citation_implode( $elements ) ]['margin-right'] = '-' . $widgets_margin['padding-right'];

}
